@@ -2,19 +2,13 @@ package Data::Postponed::Forever;
 use strict;
 use vars ( '@ISA' );
 
-@ISA = 'Data::Postponed';
-
-sub new {
-    bless [
-	   Data::Postponed::_ByValueOrReference( $_[1] )
-	  ],
-	    $_[0];
+BEGIN {
+    @ISA = 'Data::Postponed';
 }
 
-sub DESTROY {} # Don't bother AUTOLOADing this
-
 1;
 
+
 __END__
 
 =head1 NAME
